@@ -50,7 +50,7 @@ class LatexSourceGenerator:
     def __init__(self, circuit: QuantumCircuit):
         self._quantum_circuit = circuit
         self._parser = CircuitParser(circuit)
-        self._circuit_data = self._parser.gate_info
+        self._circuit_data = self._parser.parsed_circuit
         self._circuit = np.array([[]])
         self._head = r"""
 \documentclass[border={-2pt 5pt 5pt -7pt}]{standalone}
@@ -107,10 +107,10 @@ class LatexSourceGenerator:
                 else:
                     self._gate(current_layer_latex, gate)
 
-            self._circuit = np.column_stack([self._circuit, current_layer_latex])
+            self._circuit = np.column_stack([self._circuit, current_layer_latex])  # type: ignore
         wires = np.array([[r"\qw"] for _ in range(qubit_count)])
-        circuit_with_label = np.column_stack([input_label, self._circuit, wires])
-        body = self._matrix_to_qcircuit_style(circuit_with_label)  # type: ignore
+        circuit_with_label = np.column_stack([input_label, self._circuit, wires])  # type: ignore
+        body = self._matrix_to_qcircuit_style(circuit_with_label)
 
         return self._head + body + self._tail
 
